@@ -1,13 +1,15 @@
 """This module contains vpype core and its API."""
 
+from ._deprecated import *
 from .config import *
-from .decorators import *
+from .filters import *
 from .geometry import *
 from .io import *
-from .layers import *
 from .line_index import *
+from .metadata import *
 from .model import *
 from .primitives import *
+from .text import *
 from .utils import *
 
 
