@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import logging
 import os
 import random
 import shlex
 import sys
 import traceback
-from typing import TYPE_CHECKING, Any, Callable, Iterable, List, Optional, TextIO, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Iterable, TextIO, Union, cast
 
 import click
 import numpy as np
@@ -34,7 +36,7 @@ class GroupedGroup(click.Group):
     def command(self, *args, **kwargs):
         """Gather the command help groups"""
         help_group = kwargs.pop("group", None)
-        decorator = super(GroupedGroup, self).command(*args, **kwargs)
+        decorator = super().command(*args, **kwargs)
 
         def wrapper(f):
             cmd = decorator(f)
@@ -100,7 +102,7 @@ class _BrokenCommand(click.Command):  # pragma: no cover
             "\nWarning: entry point could not be loaded. Contact "
             "its author for help.\n\n\b\n" + traceback.format_exc()
         )
-        self.short_help = "\u2020 Warning: could not load plugin. See `%s %s --help`." % (
+        self.short_help = "\u2020 Warning: could not load plugin. See `{} {} --help`.".format(
             util_name,
             self.name,
         )
@@ -114,9 +116,13 @@ class _BrokenCommand(click.Command):  # pragma: no cover
         return args
 
 
-# noinspection PyUnusedLocal,PyUnresolvedReferences
-@click.group(cls=GroupedGroup, chain=True)
+_PLUGINS_LOADED = False
+
+
+# noinspection PyUnusedLocal
+@click.group(cls=GroupedGroup, chain=True, invoke_without_command=True)
 @click.version_option(version=vp.__version__, message="%(prog)s %(version)s")
+@click.option("-h", "--help", "help_flag", is_flag=True, help="Show this message and exit.")
 @click.option("-v", "--verbose", count=True)
 @click.option("-I", "--include", type=click.Path(), help="Load commands from a command file.")
 @click.option(
@@ -130,7 +136,15 @@ class _BrokenCommand(click.Command):  # pragma: no cover
     "-c", "--config", type=click.Path(exists=True), help="Load an additional config file."
 )
 @click.pass_context
-def cli(ctx, verbose, include, history, seed, config):
+def cli(
+    ctx: click.Context,
+    help_flag: bool,
+    verbose: int,
+    include: bool,
+    history: bool,
+    seed: int,
+    config: str,
+):
     """Execute the sequence of commands passed in argument.
 
     The available commands are listed below. Information on each command may be obtained using:
@@ -181,15 +195,30 @@ def cli(ctx, verbose, include, history, seed, config):
     # 1) Deferred plug-in loading avoid circular import between vpype and vpype_cli when plug-
     #    in uses deprecated APIs.
     # 2) Avoids the PyCharm type error with CliRunner.invoke()
-    for entry_point in iter_entry_points("vpype.plugins"):
-        # noinspection PyBroadException
-        try:
-            ctx.command.add_command(entry_point.load())
-        except Exception:
-            # Catch this so a busted plugin doesn't take down the CLI.
-            # Handled by registering a dummy command that does nothing
-            # other than explain the error.
-            ctx.command.add_command(_BrokenCommand(entry_point.name))
+    global _PLUGINS_LOADED
+    if not _PLUGINS_LOADED:
+        _PLUGINS_LOADED = True
+        for entry_point in iter_entry_points("vpype.plugins"):
+            # noinspection PyBroadException
+            try:
+                cast(click.Group, ctx.command).add_command(entry_point.load())
+            except Exception:
+                # Catch this so a busted plugin doesn't take down the CLI.
+                # Handled by registering a dummy command that does nothing
+                # other than explain the error.
+                cast(click.Group, ctx.command).add_command(_BrokenCommand(entry_point.name))
+
+    # Manual handling of the help to work around circular import issues.
+    # Background: when importing plug-ins in the style of `click-plugin` (decorator, so plug-
+    # ins are loaded during the loading of `cli` itself), plug-in may not import things from
+    # `vpype_cli` since it is still partially loaded. Plug-ins are thus loaded when `cli` is
+    # actually executed (see previous lines). As a result, the Click's default behaviour for
+    # handling `--help` (i.e. print and exit *before* even executing `cli`) is unable to list
+    # the plug-ins. This is addressed by manually handling the top-level `--help` parameter
+    # *after* plug-ins are loaded.
+    if help_flag:
+        print(ctx.command.get_help(ctx))
+        sys.exit(0)
 
     # We use the command string as context object, mainly for the purpose of the `write`
     # command. This is a bit of a hack, and will need to be updated if we ever need more state
@@ -216,9 +245,9 @@ if TYPE_CHECKING:  # pragma: no cover
     cli = cast(GroupedGroup, cli)
 
 
-# noinspection PyShadowingNames,PyUnusedLocal
+# noinspection PyUnusedLocal
 @cli.result_callback()
-def process_pipeline(processors, verbose, include, history, seed, config):
+def process_pipeline(processors, help_flag, verbose, include, history, seed, config):
     execute_processors(processors, State())
 
 
@@ -235,8 +264,8 @@ def execute_processors(processors: Iterable[ProcessorType], state: State) -> Non
         generated geometries
     """
 
-    outer_processors: List[Any] = []  # gather commands outside of top-level blocks
-    top_level_processors: List[Any] = []  # gather commands inside of top-level blocks
+    outer_processors: list[Any] = []  # gather commands outside of top-level blocks
+    top_level_processors: list[Any] = []  # gather commands inside of top-level blocks
     block = None  # save the current top-level block's block layer_processor
     nested_count = 0  # block depth counter
     expect_block = False  # set to True by `begin` command
@@ -332,7 +361,7 @@ def end():
     return EndBlock()
 
 
-def extract_arguments(f: TextIO) -> List[str]:
+def extract_arguments(f: TextIO) -> list[str]:
     """Read the content of a file-like object and extract the corresponding argument list.
 
     Everything following a '#' is ignored until end of line. Any whitespace is considered
@@ -351,7 +380,7 @@ def extract_arguments(f: TextIO) -> List[str]:
     return args
 
 
-def preprocess_argument_list(args: List[str], cwd: Union[str, None] = None) -> List[str]:
+def preprocess_argument_list(args: list[str], cwd: str | None = None) -> list[str]:
     """Preprocess an argument list, replacing 'include' options by the corresponding file's
     content.
 
@@ -386,7 +415,7 @@ def preprocess_argument_list(args: List[str], cwd: Union[str, None] = None) -> L
                     file_path = os.path.join(cwd, file_path)
                 dir_path = os.path.dirname(file_path)
 
-                with open(file_path, "r") as f:
+                with open(file_path) as f:
                     result.extend(preprocess_argument_list(extract_arguments(f), dir_path))
         else:
             result.append(arg)
@@ -395,7 +424,7 @@ def preprocess_argument_list(args: List[str], cwd: Union[str, None] = None) -> L
 
 
 def execute(
-    pipeline: str, document: Optional[vp.Document] = None, global_opt: str = ""
+    pipeline: str, document: vp.Document | None = None, global_opt: str = ""
 ) -> vp.Document:
     """Execute a vpype pipeline.
 
