@@ -1,12 +1,13 @@
 """
 Qt Viewer
 """
+from __future__ import annotations
+
 import functools
 import logging
 import math
 import os
 import sys
-from typing import Optional, Union
 
 import moderngl as mgl
 from PySide2.QtCore import QEvent, QSettings, QSize, Qt, Signal
@@ -54,7 +55,7 @@ class QtViewerWidget(QGLWidget):
 
     mouse_coords = Signal(str)
 
-    def __init__(self, document: Optional[vp.Document] = None, parent=None):
+    def __init__(self, document: vp.Document | None = None, parent=None):
         """Constructor.
         Args:
             document: the document to display
@@ -78,7 +79,7 @@ class QtViewerWidget(QGLWidget):
         self._factor = 1.0
 
         # deferred initialization in initializeGL()
-        self._ctx: Optional[mgl.Context] = None
+        self._ctx: mgl.Context | None = None
         self._screen = None
         self.engine = Engine(
             view_mode=ViewMode.OUTLINE, show_pen_up=False, render_cb=self.update
@@ -97,11 +98,11 @@ class QtViewerWidget(QGLWidget):
             f"logicalDotsPerInch={screen.logicalDotsPerInch()}, "
         )
 
-    def document(self) -> Optional[vp.Document]:
+    def document(self) -> vp.Document | None:
         """Return the :class:`vpype.Document` currently assigned to the widget."""
         return self._document
 
-    def set_document(self, document: Optional[vp.Document]) -> None:
+    def set_document(self, document: vp.Document | None) -> None:
         """Assign a new :class:`vpype.Document` to the widget."""
         self._document = document
         self.engine.document = document
@@ -120,8 +121,13 @@ class QtViewerWidget(QGLWidget):
         self._ctx = mgl.create_context()
         logging.info(f"Context info: {self._ctx.info}")
 
-        self._ctx.viewport = (0, 0, self._factor * self.width(), self._factor * self.height())
         self._screen = self._ctx.detect_framebuffer()
+        self._screen.viewport = (
+            0,
+            0,
+            int(self._factor * self.width()),
+            int(self._factor * self.height()),
+        )
 
         self.engine.post_init(
             self._ctx, int(self._factor * self.width()), int(self._factor * self.height())
@@ -136,8 +142,9 @@ class QtViewerWidget(QGLWidget):
 
     def resizeGL(self, w: int, h: int) -> None:
         self.engine.resize(w, h)
-        if self._ctx:
-            self._ctx.viewport = (0, 0, w, h)
+
+        if self._screen:
+            self._screen.viewport = (0, 0, int(w), int(h))
 
     def mousePressEvent(self, evt):
         self._last_mouse_x = evt.x()
@@ -210,7 +217,7 @@ class QtViewer(QWidget):
 
     def __init__(
         self,
-        document: Optional[vp.Document] = None,
+        document: vp.Document | None = None,
         view_mode: ViewMode = ViewMode.PREVIEW,
         show_pen_up: bool = False,
         show_points: bool = False,
@@ -282,17 +289,27 @@ class QtViewer(QWidget):
         act = view_mode_menu.addAction("Preview Mode Options:")
         act.setEnabled(False)
         # pen width
-        pen_width_menu = view_mode_menu.addMenu("Pen Width")
+        pen_width_menu = view_mode_menu.addMenu("Default Pen Width")
+        act = pen_width_menu.addAction("Override")
+        act.setCheckable(True)
+        act.toggled.connect(self.set_override_pen_width)
+        pen_width_menu.addSeparator()
         act_grp = PenWidthActionGroup(0.3, parent=pen_width_menu)
-        act_grp.triggered.connect(self.set_pen_width_mm)
+        act_grp.triggered.connect(self.set_default_pen_width_mm)
         pen_width_menu.addActions(act_grp.actions())
-        self.set_pen_width_mm(0.3)
+        self.set_default_pen_width_mm(0.3)
+
         # pen opacity
-        pen_opacity_menu = view_mode_menu.addMenu("Pen Opacity")
+        pen_opacity_menu = view_mode_menu.addMenu("Default Pen Opacity")
+        act = pen_opacity_menu.addAction("Override")
+        act.setCheckable(True)
+        act.toggled.connect(self.set_override_pen_opacity)
+        pen_opacity_menu.addSeparator()
         act_grp = PenOpacityActionGroup(0.8, parent=pen_opacity_menu)
-        act_grp.triggered.connect(self.set_pen_opacity)
+        act_grp.triggered.connect(self.set_default_pen_opacity)
         pen_opacity_menu.addActions(act_grp.actions())
-        self.set_pen_opacity(0.8)
+        self.set_default_pen_opacity(0.8)
+
         # debug view
         if _DEBUG_ENABLED:
             act = view_mode_menu.addAction("Debug View")
@@ -383,7 +400,7 @@ class QtViewer(QWidget):
     def add_side_widget(self, widget: QWidget) -> None:
         self._hlayout.addWidget(widget)
 
-    def set_document(self, document: Optional[vp.Document]) -> None:
+    def set_document(self, document: vp.Document | None) -> None:
         self._viewer_widget.set_document(document)
         self._update_layer_menu()
 
@@ -419,15 +436,21 @@ class QtViewer(QWidget):
     def set_show_points(self, show_points: bool) -> None:
         self._viewer_widget.engine.show_points = show_points
 
-    def set_pen_width_mm(self, value: Union[float, QAction]) -> None:
+    def set_default_pen_width_mm(self, value: float | QAction) -> None:
         if isinstance(value, QAction):
             value = value.data()
-        self._viewer_widget.engine.pen_width = value / 25.4 * 96.0
+        self._viewer_widget.engine.default_pen_width = value / 25.4 * 96.0
 
-    def set_pen_opacity(self, value: Union[float, QAction]) -> None:
+    def set_default_pen_opacity(self, value: float | QAction) -> None:
         if isinstance(value, QAction):
             value = value.data()
-        self._viewer_widget.engine.pen_opacity = value
+        self._viewer_widget.engine.default_pen_opacity = value
+
+    def set_override_pen_width(self, value: bool) -> None:
+        self._viewer_widget.engine.override_pen_width = value
+
+    def set_override_pen_opacity(self, value: bool) -> None:
+        self._viewer_widget.engine.override_pen_opacity = value
 
     def set_debug(self, debug: bool) -> None:
         self._viewer_widget.engine.debug = debug
